@@ -12,7 +12,7 @@ import numpy as np
 import json
 from datetime import datetime, date, timedelta
 
-validExIDs = ['SSE','SZE','SFE',"INE","DCE","ZCE","CCF","SGE"]
+validExIDs = ['SSE','SZE','SFE',"INE","DCE","ZCE","CCF","SGE","GFE"]
 
 def convert_security(security):
     insts = security.split('.')
@@ -163,7 +163,7 @@ def get_securities_list(stype="all",dateWindow=None, exchange="all"):
         print("stype不合法, 合法值如下： [\'all\', \'options\', \'futures\']")
         
         return None
-    validExchanges =['DCE', 'SSE',"SFE","ZCE","INE","CCF","ALL"]
+    validExchanges =['DCE', 'SSE',"SFE","ZCE","INE","CCF","GFE","ALL"]
     exID = exchange.upper()
     if not exID in validExchanges:
         print("exchange不合法, 合法值如下:", validExchanges)
@@ -285,6 +285,10 @@ def readProd(instid):
         prod = prod[:1]
     return prod
 
+@assert_auth
+def get_all_products():
+    return qedataClient().instance()('get_all_products',**locals())
+
 @assert_auth
 def get_realtime_minute_prices(insts):
     if isinstance(insts, str):
@@ -421,6 +425,120 @@ def get_bar_data(instids, tradingday, count=0):
     except Exception as e:
         print("get_bar_data Error:", e.__traceback__.tb_lineno,e)
         return None
+
+@assert_auth
+def get_broker_info(broker):
+    try:
+        assert isinstance(broker, str),'broker需要是合法的期货公司代码字符串'
+        return qedataClient.instance()('get_broker_info', **locals())
+
+    except Exception as e:
+        print("get_broker_info Error:", e.__traceback__.tb_lineno,e)
+        return None
+
+@assert_auth
+def get_valid_instID(instid):
+    try:
+        assert isinstance(instid, str) and len(instid)>=5,'instid需要是合法的合约代码字符串'
+        inst = instid
+        prod = inst[:2]
+        if prod[1].isdigit():
+            prod = inst[:1]
+        if instid.find('9999') >= 0:
+            return get_dominant_instID(prod)
+        elif instid.find('9998') >= 0:
+            return get_dominant_instID(prod,code='9998')
+        else:
+            return qedataClient.instance()('get_valid_instID', **locals())
+
+    except Exception as e:
+        print("get_valid_instID Error:", e.__traceback__.tb_lineno,e)
+        return None
+
+@assert_auth
+def is_valid_instID(instid):
+    try:
+        assert isinstance(instid, str) and len(instid)>=9,'instid需要是合法的合约代码字符串'
+        instid = instid.upper()
+        instid = instid.replace('.','_')
+        instid = instid.replace('-','_')
+        if instid.find('(T+D)') >= 0:
+            instid.replace('(T+D)','_T_D')
+        if instid in ['510300_SSE','510050_SSE']:
+            return True
+        elif instid in ['AG_T_D_SGE','AU_T_D_SGE','AU99_99_SGE','MAU_T_D_SGE']:
+            return True
+        else:
+            return qedataClient.instance()('is_valid_instID', **locals())
+
+    except Exception as e:
+        print("is_valid_instID Error:", e.__traceback__.tb_lineno,e)
+        return None
+
+@assert_auth
+def is_valid_trade_time(instid, curtime):
+    try:
+        assert isinstance(instid, str) and len(instid)>=9,'instid需要是合法的合约代码字符串'
+        assert isinstance(curtime, datetime), 'curtime必须是datetime类型'
+        weekday = curtime.weekday()
+        timenum = curtime.hour * 100 + curtime.minute
+        del curtime
+        return qedataClient.instance()('is_valid_trade_time', **locals())
+
+    except Exception as e:
+        print("is_valid_trade_time Error:", e.__traceback__.tb_lineno,e)
+        return None
+
+@assert_auth
+def get_product_spot_price(symbol, start_date, end_date):
+    try:
+        if isinstance(start_date, datetime):
+            start_date = start_date.strftime('%Y-%m-%d')
+        elif isinstance(start_date, str):
+            if len(start_date) != 10 or not is_valid_date(start_date):
+                print('Invalid start_date')
+                return None
+        if isinstance(end_date, datetime) :
+            end_date = end_date.strftime('%Y-%m-%d')
+        elif isinstance(end_date, str):
+            if len(end_date) != 10 or not is_valid_date(end_date):
+                print('Invalid end_date')
+                return None
+        return qedataClient.instance()('get_product_spot_price', **locals())
+    except Exception as e:
+        print("get_product_spot_price Error:", e.__traceback__.tb_lineno,e)
+        return None
+
+@assert_auth
+def get_product_invent_orders(symbol, start_date, end_date):
+    try:
+        if isinstance(start_date, datetime):
+            start_date = start_date.strftime('%Y-%m-%d')
+        elif isinstance(start_date, str):
+            if len(start_date) != 10 or not is_valid_date(start_date):
+                print('Invalid start_date')
+                return None
+        if isinstance(end_date, datetime):
+            end_date = end_date.strftime('%Y-%m-%d')
+        elif isinstance(end_date, str):
+            if len(end_date) != 10 or not is_valid_date(end_date):
+                print('Invalid end_date')
+                return None
+        return qedataClient.instance()('get_product_invent_orders', **locals())
+    except Exception as e:
+        print("get_product_invent_orders Error:", e.__traceback__.tb_lineno,e)
+        return None
+
+
+
+#########################algo trades#####################################
+@assert_auth
+def get_package_address(plugin, plat, version, macaddr):
+        return qedataClient.instance()('get_package_address', **locals())
+
+@assert_auth
+def get_plugin_permission(plugin, plat, version, macaddr, key, signval):
+        return qedataClient.instance()('get_plugin_permission', **locals())
         
 ##############################stratmarket############################
 def sm_get_clone_strat_list():
@@ -449,6 +567,71 @@ def sm_get_clone_strat_position(strats:list):
     except Exception as e:
         print("get_clone_strat_position Error:", e.__traceback__.tb_lineno,e)
     
+@assert_auth
+def get_instrument_broker_ranking(instid, curdate, rankname):
+    valid_rankname = ['tradevol',
+                      'longpos',
+                      'longpos_add',
+                      'longpos_reduce',
+                      'longpos_net',
+                      'shortpos',
+                      'shortpos_add',
+                      'shortpos_reduce',
+                      'shortpos_net']
+    if not rankname in valid_rankname:
+        print(f'不合法的rankname:{rankname}, rankname可以是{valid_rankname}')
+        return None
+    insts = instid.split('.')
+    instID = insts[0].upper()
+
+    if isinstance(curdate, datetime) or isinstance(curdate, date):
+        curdate = curdate.strftime('%Y-%m-%d')
+    elif isinstance(curdate, str):
+        if len(curdate) != 10 or not is_valid_date(curdate):
+            print('Invalid curdate')
+            return None
+    del insts
+    return qedataClient.instance()('get_instrument_broker_ranking', **locals())
+    
+@assert_auth
+def get_instrument_broker_holding(broker, instid, start_date, end_date):
+    insts = instid.split('.')
+    instID = insts[0].upper()
+
+    if isinstance(start_date, datetime) or isinstance(start_date, date):
+        start_date = start_date.strftime('%Y-%m-%d')
+    elif isinstance(start_date, str):
+        if len(start_date) != 10 or not is_valid_date(start_date):
+            print('Invalid start_date')
+            return None
+    if isinstance(end_date, datetime) or isinstance(end_date, date):
+        end_date = end_date.strftime('%Y-%m-%d')
+    elif isinstance(end_date, str):
+        if len(end_date) != 10 or not is_valid_date(end_date):
+            print('Invalid end_date')
+            return None
+    del insts        
+    return qedataClient.instance()('get_instrument_broker_holding', **locals())
+    
+@assert_auth
+def get_instrument_broker_pnl(broker, instid, start_date, end_date):
+    insts = instid.split('.')
+    instID = insts[0].upper()
+
+    if isinstance(start_date, datetime) or isinstance(start_date, date):
+        start_date = start_date.strftime('%Y-%m-%d')
+    elif isinstance(start_date, str):
+        if len(start_date) != 10 or not is_valid_date(start_date):
+            print('Invalid start_date')
+            return None
+    if isinstance(end_date, datetime) or isinstance(end_date, date):
+        end_date = end_date.strftime('%Y-%m-%d')
+    elif isinstance(end_date, str):
+        if len(end_date) != 10 or not is_valid_date(end_date):
+            print('Invalid end_date')
+            return None
+    del insts        
+    return qedataClient.instance()('get_instrument_broker_pnl', **locals())
 
 
 __all__ = []
@@ -456,7 +639,7 @@ __all__ = []
 def _collect_func():
     funcs = []
     for func in globals().keys():
-        if func.startswith("get") or func.startswith("sm_get"):
+        if func.startswith("get") or func.startswith("sm_get") or func.startswith("is_"):
             funcs.append(func)
     return funcs
 
