@@ -25,9 +25,9 @@ def get_plat():
     return platform.system().lower()
 
 qesdk2.auth('quantease','$1$$k7yjPQKv8AJuZERDA.eQX.')
-df = qesdk2.get_instrument_broker_pnl('东证期货','AU2306.SFE','2023-02-24','2023-02-28')
+#df = qesdk2.get_instrument_broker_pnl('东证期货','AU2306.SFE','2023-02-24','2023-02-28')
 
-#df = qesdk2.get_instrument_broker_ranking('AU2312.SFE', '2023-02-28','tradevol')
+df = qesdk2.get_product_invent_orders('CU', '2023-02-01','2023-02-14')
 print(df)
 #msg = qesdk2.get_package_address('algoex', get_plat(), get_ver(), get_mac_address())
 #print(msg)
